@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2021, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2022, Victor Ananjevsky <victor@sanana.kiev.ua>
  */
 
 #include <pango/pango.h>
@@ -231,7 +231,7 @@ menu_popup_cb (GtkTextView *w, GtkWidget *popup, gpointer d)
   if (!GTK_IS_MENU (popup))
     return;
 
-  if (options.text_data.file_op)
+  if (options.common_data.file_op)
     {
       GtkWidget *mitem;
 
@@ -285,7 +285,7 @@ key_press_cb (GtkWidget *w, GdkEventKey *key, gpointer d)
       gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (search_bar->bar), TRUE);
       return gtk_search_bar_handle_event (GTK_SEARCH_BAR (search_bar->bar), (GdkEvent *) key);
     }
-  else if (options.text_data.file_op)
+  else if (options.common_data.file_op)
     {
       if ((key->state & GDK_CONTROL_MASK) && (key->keyval == GDK_KEY_O || key->keyval == GDK_KEY_o))
         {
@@ -456,6 +456,9 @@ handle_stdin (GIOChannel * channel, GIOCondition condition, gpointer data)
       GString *string;
       GError *err = NULL;
       gint status;
+#ifdef HAVE_SOURCEVIEW
+      GtkSourceLanguage *lang = NULL;
+#endif
 
       string = g_string_new (NULL);
       while (channel->is_readable != TRUE)
@@ -524,18 +527,25 @@ handle_stdin (GIOChannel * channel, GIOCondition condition, gpointer data)
             }
         }
 
+#ifdef HAVE_SOURCEVIEW
+      if (options.source_data.lang)
+        lang = gtk_source_language_manager_get_language (gtk_source_language_manager_get_default (), options.source_data.lang);
+      else
+        {
+          gchar *ctype;
+           if (options.common_data.mime && *options.common_data.mime)
+             ctype = g_content_type_from_mime_type (options.common_data.mime);
+           else
+             ctype = g_content_type_guess (NULL, string->str, string->len, NULL);
+           lang = gtk_source_language_manager_guess_language (gtk_source_language_manager_get_default (), options.common_data.uri, ctype);
+          g_free (ctype);
+        }
+      gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (text_buffer), lang);
+#endif
+
       g_string_free (string, TRUE);
     }
 
-#ifdef HAVE_SOURCEVIEW
-  if (options.source_data.lang)
-    {
-      GtkSourceLanguage *lang = gtk_source_language_manager_get_language (gtk_source_language_manager_get_default (),
-                                                                          options.source_data.lang);
-      gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (text_buffer), lang);
-    }
-#endif
-
   return TRUE;
 }
 
@@ -587,16 +597,18 @@ fill_buffer_from_file ()
   if (options.source_data.lang)
     lang = gtk_source_language_manager_get_language (gtk_source_language_manager_get_default (), options.source_data.lang);
   else
-    lang = gtk_source_language_manager_guess_language (gtk_source_language_manager_get_default (), options.common_data.uri, NULL);
+    {
+      gchar *ctype = NULL;
+
+      if (options.common_data.mime && *options.common_data.mime)
+        ctype = g_content_type_from_mime_type (options.common_data.mime);
+      else
+        ctype = g_content_type_guess (options.common_data.uri, NULL, 0, NULL);
+      lang = gtk_source_language_manager_guess_language (gtk_source_language_manager_get_default (), options.common_data.uri, ctype);
+      g_free (ctype);
+    }
   gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (text_buffer), lang);
 #endif
-
-  if (options.common_data.editable)
-    {
-      /* move cursor at the beginnging of a buffer */
-      gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (text_buffer), &iter, 0);
-      gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (text_buffer), &iter);
-    }
 }
 
 static void
@@ -616,6 +628,22 @@ text_changed_cb (GtkTextBuffer *b, gpointer d)
   text_changed = TRUE;
 }
 
+void
+text_goto_line ()
+{
+  if (options.common_data.uri)
+    {
+      GtkTextIter iter;
+
+      while (gtk_events_pending ())
+        gtk_main_iteration ();
+
+      gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (text_buffer), &iter, options.text_data.line);
+      gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (text_buffer), &iter);
+      gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (text_view), &iter, 0, TRUE, 0, 0.5);
+    }
+}
+
 GtkWidget *
 text_create_widget (GtkWidget * dlg)
 {
@@ -767,7 +795,7 @@ text_create_widget (GtkWidget * dlg)
   /* Add keyboard handler */
   g_signal_connect (text_view, "key-press-event", G_CALLBACK (key_press_cb), dlg);
 
-  if (options.text_data.file_op)
+  if (options.common_data.file_op)
     {
       g_signal_connect (G_OBJECT (text_buffer), "changed", G_CALLBACK (text_changed_cb), NULL);
       g_signal_connect_after (G_OBJECT (text_view), "populate-popup", G_CALLBACK (menu_popup_cb), dlg);
@@ -818,14 +846,6 @@ text_create_widget (GtkWidget * dlg)
 
   if (options.common_data.listen || options.common_data.uri == NULL)
     fill_buffer_from_stdin ();
-  else
-    {
-      /* place cursor at start of file */
-      GtkTextIter iter;
-
-      gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (text_buffer), &iter, 0);
-      gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (text_buffer), &iter);
-    }
 
   return w;
 }
